# COPR Ligenix's spec file for glpi-plugin-datainjection
#
# Copyright (c) 2021-2023 Jean-Marc Liger 
#
# Forked from:
#
# spec file for glpi-data-injection
#
# Copyright (c) 2007-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname datainjection
%global glpi_min   10.0.0
%global glpi_max   10.1.0

Name:           glpi-plugin-%{pluginname}
Version:        2.13.0
Release:        2%{?dist}
Summary:        Plugin for importing data into GLPI
Summary(fr):    Extension pour importer des données dans GLPI

License:        GPLv2+
URL:            https://github.com/pluginsGLPI/%{pluginname}

Source0:        https://github.com/pluginsGLPI/%{pluginname}/releases/download/v%{version}/glpi-%{pluginname}-%{version}.tar.bz2

BuildArch:      noarch

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif
Provides:       glpi-%{pluginname} = %{version}-%{release}
Obsoletes:      glpi-%{pluginname} <= 2.7.1
# This plugin have been renamed
Obsoletes:      glpi-data-injection < 2.7.0
Provides:       glpi-data-injection = %{version}-%{release}


%description
Plugin for importing data into GLPI

It'll can serve, for example, to :
- import machines at the delivery (electronic delivery order in CSV)
- import additional data
- import equipment not managed by OCS
- transmit from an other tool of asset management

%description -l fr
Extension pour importer des données dans GLPI

Elle pourra servir, par exemple, à :
- importer des machines à la livraison (bon de livraison électronique en CSV)
- importer des données complémentaires
- importer des matériels non gérés par OCS
- migrer depuis un autre outil de gestion de parc


%prep
%setup -q -c

grep 'define("PLUGIN_DATAINJECTION_M.._GLPI' %{pluginname}/setup.php

# remove unused files
rm %{pluginname}/testwebservice.php
rm %{pluginname}/%{pluginname}.xml
rm %{pluginname}/composer.json

# move doc files
mkdir docs
mv %{pluginname}/*.md             docs/
mv %{pluginname}/screenshots/     docs/
mv %{pluginname}/glpi_network.png docs/

# create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# empty build


%install
mkdir -p %{buildroot}%{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}

mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/%{pluginname}.png
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/ajax
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/js
%{_datadir}/glpi/plugins/%{pluginname}/pics
%{_datadir}/glpi/plugins/%{pluginname}/vendor
# data
%attr(750,apache,root) %{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}


%changelog
* Wed May 03 2023 Jean-Marc Liger <ligenix@iscp.fr> - 2.13.0-2
- Move screenshots to docs

* Mon May 01 2023 Jean-Marc Liger <ligenix@iscp.fr> - 2.13.0-1
- Version 2.13.0

* Fri Sep 16 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.12.0-1
- Version 2.12.0

* Sat Jul 30 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.11.2-1
- Version 2.11.2 for GLPI 10.0.x

* Mon Jul 18 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.10.2-1
- Version 2.10.2

* Sat Apr 02 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.10.1-1
- Version 2.10.1

* Mon May 17 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.9.0-2
- update spec file's copyright, thanks again to Remy Collet!

* Thu Apr 15 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.9.0-1
- rename to glpi-plugin-datainjection
- update to 2.9.0 for GLPI 9.5

* Thu Feb  6 2020 Remi Collet <remi@remirepo.net> - 2.7.1-1
- update to 2.7.1 for GLPI 9.4

* Sat Dec 22 2018 Remi Collet <remi@remirepo.net> - 2.7.0-1
- update to 2.7.0 for GLPI 9.4
- rename to glpi-datainjection

* Fri Oct 26 2018 Remi Collet <remi@remirepo.net> - 2.6.4-1
- update to 2.6.4

* Mon Sep 10 2018 Remi Collet <remi@remirepo.net> - 2.6.3-1
- update to 2.6.3 for GLPI 9.3

* Tue Sep  4 2018 Remi Collet <remi@remirepo.net> - 2.6.2-1
- update to 2.6.2 for GLPI 9.3

* Fri Jul  6 2018 Remi Collet <remi@remirepo.net> - 2.6.1-1
- update to 2.6.1 for GLPI 9.3

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 2.6.0-1
- update to 2.6.0 for GLPI 9.3

* Tue Jun 12 2018 Remi Collet <remi@remirepo.net> - 2.5.2-2
- allow GLPI 9.3

* Tue Jun 12 2018 Remi Collet <remi@remirepo.net> - 2.5.2-1
- update to 2.5.2 for GLPI 9.2

* Fri May 25 2018 Remi Collet <remi@remirepo.net> - 2.5.1-1
- update to 2.5.1 for GLPI 9.2

* Wed Jan 31 2018 Remi Collet <remi@remirepo.net> - 2.5.0-1
- update to 2.5.0 for GLPI 9.2

* Fri Sep 23 2016 Johan Cwiklinski <jcwiklinski AT teclib DOT com> - 2.4.2-1
- Last upstream release, 9.1 compatible

* Tue Jun 28 2016 Johan Cwiklinski <jcwiklinski AT teclib DOT com> - 2.4.1-1.1
- Change URL

* Wed Feb 24 2016 Remi Collet <Fedora@FamilleCollet.com> - 2.4.1-1
- version 2.4.1 for GLPI 0.85/0.90

* Mon Mar 31 2014 Remi Collet <Fedora@FamilleCollet.com> - 2.3.1-1
- version 2.3.1 for GLPI 0.84
  https://forge.indepnet.net/projects/datainjection/versions/1004

* Tue Nov 12 2013 Remi Collet <Fedora@FamilleCollet.com> - 2.3.0-1
- version 2.3.0 for GLPI 0.84
  https://forge.indepnet.net/projects/datainjection/versions/934

* Wed Jun 13 2012 Remi Collet <Fedora@FamilleCollet.com> - 2.2.1-1
- version 2.2.1
  https://forge.indepnet.net/projects/datainjection/versions/748

* Thu Apr 19 2012 Remi Collet <Fedora@FamilleCollet.com> - 2.2.0-1
- version 2.2.0 finale
  https://forge.indepnet.net/projects/datainjection/versions/645

* Fri Apr 06 2012 Remi Collet <Fedora@FamilleCollet.com> - 2.2.0-0.1.svn703
- new snapshot

* Sun Feb 26 2012 Remi Collet <Fedora@FamilleCollet.com> - 2.2.0-0.1.svn674
- update to 2.2.0 for glpi 0.83 RC (svn snapshot)

* Tue Jan 10 2012 Remi Collet <Fedora@FamilleCollet.com> - 2.1.4-1
- update to 2.1.4
  https://forge.indepnet.net/projects/datainjection/versions/671

* Sun Dec 11 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.1.3-1
- update to 2.1.3
  https://forge.indepnet.net/projects/datainjection/versions/663

* Sat Nov 26 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.1.2-1
- update to 2.1.2
  https://forge.indepnet.net/projects/datainjection/versions/661

* Sat Nov 12 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.1.1-1
- update to 2.1.1

* Sun Oct 16 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.1.0-1
- update to 2.1.0 finale version

* Tue Sep 20 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.1.0-0.2.svn596
- new snapshot

* Sun Jul 24 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.1.0-0.1.svn593
- update to 2.1.0 for glpi 0.80 (svn snapshot)

* Sat Jun 11 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.0.2-1
- update to 2.0.2
  https://forge.indepnet.net/projects/datainjection/versions/544

* Tue Mar  8 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.0.1-1.beta
- update to 2.0.1-beta

* Wed Jan 19 2011 Remi Collet <Fedora@FamilleCollet.com> - 2.0.0-0.1.beta
- update to 2.0.0-beta

* Fri Dec 10 2010 Remi Collet <Fedora@FamilleCollet.com> - 1.7.2-1
- update to 1.7.2
- fix URL + Source (link to new forge)

* Wed Sep 09 2009 Remi Collet <Fedora@FamilleCollet.com> - 1.7.0-1
- update to 1.7.0

* Tue Aug 18 2009 Remi Collet <Fedora@FamilleCollet.com> - 1.6.0-1
- update to 1.6.0 finale for glpi 0.72

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Apr 21 2009 Remi Collet <Fedora@FamilleCollet.com> - 1.5.1-1
- update to 1.5.1

* Fri Mar 13 2009 Remi Collet <Fedora@FamilleCollet.com> - 1.4.0-1
- update to 1.4.0
- spec cleanup

* Sat Jul 12 2008 Remi Collet <Fedora@FamilleCollet.com> - 1.2-1
- update to 1.2 for glpi 0.71

* Sun Jan 13 2008 Remi Collet <Fedora@FamilleCollet.com> - 1.1-1
- update to 1.1
- tag lang files

* Tue Dec 25 2007 Remi Collet <Fedora@FamilleCollet.com> - 1.0-1
- update to 1.0 finale
- add patch 5653 (lang fix)

* Sat Aug 25 2007 Remi Collet <RPMS@FamilleCollet.com> - 1.0-0.20070825
- Initial RPM

